# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_gui.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(718, 357)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.login_link = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.login_link.setGeometry(QtCore.QRect(0, -5, 261, 51))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(16)
        font.setBold(False)
        font.setWeight(50)
        self.login_link.setFont(font)
        self.login_link.setAutoFillBackground(False)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("../img/poe.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.login_link.setIcon(icon)
        self.login_link.setIconSize(QtCore.QSize(40, 40))
        self.login_link.setAutoRepeatDelay(1000)
        self.login_link.setObjectName("login_link")
        self.select_tab = QtWidgets.QComboBox(self.centralwidget)
        self.select_tab.setGeometry(QtCore.QRect(90, 110, 241, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.select_tab.setFont(font)
        self.select_tab.setEditable(True)
        self.select_tab.setObjectName("select_tab")
        self.select_league = QtWidgets.QComboBox(self.centralwidget)
        self.select_league.setGeometry(QtCore.QRect(90, 80, 241, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.select_league.setFont(font)
        self.select_league.setEditable(True)
        self.select_league.setObjectName("select_league")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(10, 80, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(10, 110, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.count_report_string = QtWidgets.QLabel(self.centralwidget)
        self.count_report_string.setGeometry(QtCore.QRect(10, 280, 701, 41))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(14)
        self.count_report_string.setFont(font)
        self.count_report_string.setObjectName("count_report_string")
        self.refresh_link = QtWidgets.QCommandLinkButton(self.centralwidget)
        self.refresh_link.setGeometry(QtCore.QRect(250, 0, 91, 41))
        font = QtGui.QFont()
        font.setFamily("Segoe UI")
        font.setPointSize(16)
        font.setBold(False)
        font.setWeight(50)
        self.refresh_link.setFont(font)
        self.refresh_link.setAutoFillBackground(False)
        icon = QtGui.QIcon.fromTheme("refresh")
        self.refresh_link.setIcon(icon)
        self.refresh_link.setIconSize(QtCore.QSize(40, 40))
        self.refresh_link.setAutoRepeatDelay(1000)
        self.refresh_link.setObjectName("refresh_link")
        self.count_weapons = QtWidgets.QProgressBar(self.centralwidget)
        self.count_weapons.setGeometry(QtCore.QRect(440, 10, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_weapons.setFont(font)
        self.count_weapons.setProperty("value", 0)
        self.count_weapons.setObjectName("count_weapons")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(360, 10, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.count_helms = QtWidgets.QProgressBar(self.centralwidget)
        self.count_helms.setGeometry(QtCore.QRect(440, 40, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_helms.setFont(font)
        self.count_helms.setProperty("value", 0)
        self.count_helms.setObjectName("count_helms")
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setGeometry(QtCore.QRect(360, 40, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.label_5 = QtWidgets.QLabel(self.centralwidget)
        self.label_5.setGeometry(QtCore.QRect(360, 100, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.count_bodies = QtWidgets.QProgressBar(self.centralwidget)
        self.count_bodies.setGeometry(QtCore.QRect(440, 70, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_bodies.setFont(font)
        self.count_bodies.setProperty("value", 0)
        self.count_bodies.setObjectName("count_bodies")
        self.label_6 = QtWidgets.QLabel(self.centralwidget)
        self.label_6.setGeometry(QtCore.QRect(360, 70, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.count_legs = QtWidgets.QProgressBar(self.centralwidget)
        self.count_legs.setGeometry(QtCore.QRect(440, 100, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_legs.setFont(font)
        self.count_legs.setProperty("value", 0)
        self.count_legs.setObjectName("count_legs")
        self.label_7 = QtWidgets.QLabel(self.centralwidget)
        self.label_7.setGeometry(QtCore.QRect(360, 160, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.count_amulets = QtWidgets.QProgressBar(self.centralwidget)
        self.count_amulets.setGeometry(QtCore.QRect(440, 220, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_amulets.setFont(font)
        self.count_amulets.setProperty("value", 0)
        self.count_amulets.setObjectName("count_amulets")
        self.label_8 = QtWidgets.QLabel(self.centralwidget)
        self.label_8.setGeometry(QtCore.QRect(360, 190, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.count_boots = QtWidgets.QProgressBar(self.centralwidget)
        self.count_boots.setGeometry(QtCore.QRect(440, 130, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_boots.setFont(font)
        self.count_boots.setProperty("value", 0)
        self.count_boots.setObjectName("count_boots")
        self.label_9 = QtWidgets.QLabel(self.centralwidget)
        self.label_9.setGeometry(QtCore.QRect(360, 130, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.count_gloves = QtWidgets.QProgressBar(self.centralwidget)
        self.count_gloves.setGeometry(QtCore.QRect(440, 160, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_gloves.setFont(font)
        self.count_gloves.setProperty("value", 0)
        self.count_gloves.setObjectName("count_gloves")
        self.count_belts = QtWidgets.QProgressBar(self.centralwidget)
        self.count_belts.setGeometry(QtCore.QRect(440, 190, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_belts.setFont(font)
        self.count_belts.setProperty("value", 0)
        self.count_belts.setObjectName("count_belts")
        self.label_10 = QtWidgets.QLabel(self.centralwidget)
        self.label_10.setGeometry(QtCore.QRect(360, 220, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_10.setFont(font)
        self.label_10.setObjectName("label_10")
        self.label_12 = QtWidgets.QLabel(self.centralwidget)
        self.label_12.setGeometry(QtCore.QRect(360, 250, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_12.setFont(font)
        self.label_12.setObjectName("label_12")
        self.count_rings = QtWidgets.QProgressBar(self.centralwidget)
        self.count_rings.setGeometry(QtCore.QRect(440, 250, 271, 23))
        font = QtGui.QFont()
        font.setFamily("Bahnschrift")
        font.setPointSize(10)
        self.count_rings.setFont(font)
        self.count_rings.setProperty("value", 0)
        self.count_rings.setObjectName("count_rings")
        self.sets_target = QtWidgets.QSpinBox(self.centralwidget)
        self.sets_target.setGeometry(QtCore.QRect(280, 200, 51, 22))
        self.sets_target.setProperty("value", 8)
        self.sets_target.setObjectName("sets_target")
        self.label_11 = QtWidgets.QLabel(self.centralwidget)
        self.label_11.setGeometry(QtCore.QRect(200, 200, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.item_ = QtWidgets.QLabel(self.centralwidget)
        self.item_.setGeometry(QtCore.QRect(10, 140, 81, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_.setFont(font)
        self.item_.setObjectName("item_")
        self.item_1 = QtWidgets.QLabel(self.centralwidget)
        self.item_1.setEnabled(False)
        self.item_1.setGeometry(QtCore.QRect(10, 170, 91, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_1.setFont(font)
        self.item_1.setObjectName("item_1")
        self.filter_mode = QtWidgets.QComboBox(self.centralwidget)
        self.filter_mode.setEnabled(False)
        self.filter_mode.setGeometry(QtCore.QRect(110, 170, 221, 22))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.filter_mode.setFont(font)
        self.filter_mode.setObjectName("filter_mode")
        self.item_2 = QtWidgets.QLabel(self.centralwidget)
        self.item_2.setEnabled(False)
        self.item_2.setGeometry(QtCore.QRect(10, 200, 111, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.item_2.setFont(font)
        self.item_2.setObjectName("item_2")
        self.recipe_chaos = QtWidgets.QRadioButton(self.centralwidget)
        self.recipe_chaos.setEnabled(False)
        self.recipe_chaos.setGeometry(QtCore.QRect(70, 200, 91, 17))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.recipe_chaos.setFont(font)
        self.recipe_chaos.setChecked(True)
        self.recipe_chaos.setObjectName("recipe_chaos")
        self.recipe_type = QtWidgets.QButtonGroup(MainWindow)
        self.recipe_type.setObjectName("recipe_type")
        self.recipe_type.addButton(self.recipe_chaos)
        self.recipe_regal = QtWidgets.QRadioButton(self.centralwidget)
        self.recipe_regal.setEnabled(False)
        self.recipe_regal.setGeometry(QtCore.QRect(70, 220, 91, 17))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.recipe_regal.setFont(font)
        self.recipe_regal.setObjectName("recipe_regal")
        self.recipe_type.addButton(self.recipe_regal)
        self.item_filter_browse = QtWidgets.QPushButton(self.centralwidget)
        self.item_filter_browse.setGeometry(QtCore.QRect(90, 140, 241, 23))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(10)
        self.item_filter_browse.setFont(font)
        self.item_filter_browse.setObjectName("item_filter_browse")
        self.client_secret_input = QtWidgets.QLineEdit(self.centralwidget)
        self.client_secret_input.setGeometry(QtCore.QRect(90, 50, 241, 20))
        self.client_secret_input.setObjectName("client_secret_input")
        self.label_13 = QtWidgets.QLabel(self.centralwidget)
        self.label_13.setGeometry(QtCore.QRect(10, 50, 71, 21))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(12)
        self.label_13.setFont(font)
        self.label_13.setObjectName("label_13")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 718, 21))
        self.menubar.setObjectName("menubar")
        self.menuLinks = QtWidgets.QMenu(self.menubar)
        self.menuLinks.setObjectName("menuLinks")
        self.menuSettings = QtWidgets.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionFilterblade_xyz = QtWidgets.QAction(MainWindow)
        self.actionFilterblade_xyz.setObjectName("actionFilterblade_xyz")
        self.actionChipy_dev = QtWidgets.QAction(MainWindow)
        self.actionChipy_dev.setObjectName("actionChipy_dev")
        self.actionPathOfExile_com = QtWidgets.QAction(MainWindow)
        self.actionPathOfExile_com.setObjectName("actionPathOfExile_com")
        self.actionPathOfBuilding_com = QtWidgets.QAction(MainWindow)
        self.actionPathOfBuilding_com.setObjectName("actionPathOfBuilding_com")
        self.actionCraftOfExile_com = QtWidgets.QAction(MainWindow)
        self.actionCraftOfExile_com.setObjectName("actionCraftOfExile_com")
        self.actionMap_RegEx = QtWidgets.QAction(MainWindow)
        self.actionMap_RegEx.setObjectName("actionMap_RegEx")
        self.actionVorici_Calculator = QtWidgets.QAction(MainWindow)
        self.actionVorici_Calculator.setObjectName("actionVorici_Calculator")
        self.actionPoE_Ninja = QtWidgets.QAction(MainWindow)
        self.actionPoE_Ninja.setObjectName("actionPoE_Ninja")
        self.actionPoE_Lab = QtWidgets.QAction(MainWindow)
        self.actionPoE_Lab.setObjectName("actionPoE_Lab")
        self.actionAwakened_PoE_Trade = QtWidgets.QAction(MainWindow)
        self.actionAwakened_PoE_Trade.setObjectName("actionAwakened_PoE_Trade")
        self.actionInput_ClientSecret = QtWidgets.QAction(MainWindow)
        self.actionInput_ClientSecret.setObjectName("actionInput_ClientSecret")
        self.menuLinks.addAction(self.actionChipy_dev)
        self.menuLinks.addSeparator()
        self.menuLinks.addAction(self.actionPathOfExile_com)
        self.menuLinks.addAction(self.actionPathOfBuilding_com)
        self.menuLinks.addAction(self.actionCraftOfExile_com)
        self.menuLinks.addAction(self.actionFilterblade_xyz)
        self.menuLinks.addAction(self.actionMap_RegEx)
        self.menuLinks.addAction(self.actionVorici_Calculator)
        self.menuLinks.addAction(self.actionPoE_Ninja)
        self.menuLinks.addAction(self.actionPoE_Lab)
        self.menuLinks.addAction(self.actionAwakened_PoE_Trade)
        self.menuSettings.addAction(self.actionInput_ClientSecret)
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuLinks.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.login_link.setText(_translate("MainWindow", "Log In?"))
        self.label.setText(_translate("MainWindow", "League:"))
        self.label_2.setText(_translate("MainWindow", "Tab:"))
        self.count_report_string.setText(_translate("MainWindow", "TextLabel"))
        self.refresh_link.setText(_translate("MainWindow", "Refresh"))
        self.label_3.setText(_translate("MainWindow", "Weapons"))
        self.label_4.setText(_translate("MainWindow", "Helms"))
        self.label_5.setText(_translate("MainWindow", "Legs"))
        self.label_6.setText(_translate("MainWindow", "Bodies"))
        self.label_7.setText(_translate("MainWindow", "Gloves"))
        self.label_8.setText(_translate("MainWindow", "Belts"))
        self.label_9.setText(_translate("MainWindow", "Boots"))
        self.label_10.setText(_translate("MainWindow", "Amulets"))
        self.label_12.setText(_translate("MainWindow", "Rings"))
        self.label_11.setText(_translate("MainWindow", "Set goal:"))
        self.item_.setText(_translate("MainWindow", "Item Fitler:"))
        self.item_1.setText(_translate("MainWindow", "Filter Mode:"))
        self.item_2.setText(_translate("MainWindow", "Recipe:"))
        self.recipe_chaos.setText(_translate("MainWindow", "Chaos (i60+)"))
        self.recipe_regal.setText(_translate("MainWindow", "Regal (i70+)"))
        self.item_filter_browse.setText(_translate("MainWindow", "Browse"))
        self.label_13.setText(_translate("MainWindow", "SECRET:"))
        self.menuLinks.setTitle(_translate("MainWindow", "Links"))
        self.menuSettings.setTitle(_translate("MainWindow", "Settings"))
        self.actionFilterblade_xyz.setText(_translate("MainWindow", "Filterblade.xyz"))
        self.actionChipy_dev.setText(_translate("MainWindow", "Chipy.dev"))
        self.actionPathOfExile_com.setText(_translate("MainWindow", "PathOfExile.com"))
        self.actionPathOfBuilding_com.setText(_translate("MainWindow", "PathOfBuilding.com"))
        self.actionCraftOfExile_com.setText(_translate("MainWindow", "CraftOfExile.com"))
        self.actionMap_RegEx.setText(_translate("MainWindow", "Map RegEx"))
        self.actionVorici_Calculator.setText(_translate("MainWindow", "Vorici Calculator"))
        self.actionPoE_Ninja.setText(_translate("MainWindow", "PoE Ninja"))
        self.actionPoE_Lab.setText(_translate("MainWindow", "PoE Lab"))
        self.actionAwakened_PoE_Trade.setText(_translate("MainWindow", "Awakened PoE Trade"))
        self.actionInput_ClientSecret.setText(_translate("MainWindow", "Input ClientSecret"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
